==> meme_4.2.0.tar.gz: meme_4.2.0/src/mhmm-dtd.h <==
char *mhmm_dtd = "<?xml version='1.0' encoding='UTF-8' standalone='yes'?>\n"
  "<!-- Document definition -->\n"
  "<!DOCTYPE MEME_HMM[\n"
  "\n"
  "  <!ELEMENT MEME_HMM (\n"
  "    command_line,\n"
  "    alphabet,\n"
  "    background_frequencies,\n"
  "    states\n"
  "  )>\n"
  "  <!ATTLIST MEME_HMM\n"
  "    version CDATA #REQUIRED\n"
  "    release_date CDATA #REQUIRED\n"
  "    type (linear|star|complete) #REQUIRED\n"
  "    motif_file CDATA #REQUIRED \n"
  "    sequence_file CDATA #IMPLIED \n"
  "    description CDATA #IMPLIED \n"
  "  >\n"
  "\n"
  "  <!ELEMENT command_line (#PCDATA)*>\n"
  "\n"
  "  <!ELEMENT alphabet (letter+)>\n"
  "  <!ATTLIST alphabet \n"
  "    id (amino_acid|nucleotide) #REQUIRED\n"
  "    length CDATA #REQUIRED\n"
  "  >\n"
  "\n"
  "  <!ELEMENT background_frequencies (alphabet_array)>\n"
  "\n"
  "  <!-- State elements -->\n"
  "  <!ELEMENT states (state+)>\n"
  "  <!ATTLIST states \n"
  "    num_states CDATA #REQUIRED\n"
  "    num_spacers CDATA #REQUIRED \n"
  "    spacer_states CDATA #REQUIRED \n"
  "  >\n"
  "\n"
  "  <!ELEMENT state (emission_probabilities?, transition*)>\n"
  "  <!ATTLIST state \n"
  "    id ID #REQUIRED\n"
  "    index CDATA #REQUIRED\n"
  "    type  (start|spacer|start_motif|mid_motif|end_motif|end) #REQUIRED\n"
  "    motif_index CDATA #IMPLIED\n"
  "    motif_id CDATA #IMPLIED\n"
  "    position CDATA #IMPLIED\n"
  "    id_char CDATA #REQUIRED\n"
  "    num_sites CDATA #REQUIRED\n"
  "  >\n"
  "\n"
  "  <!ELEMENT emission_probabilities (alphabet_array)>\n"
  "\n"
  "  <!ELEMENT transition (#PCDATA)>\n"
  "  <!ATTLIST transition to_state_index CDATA #REQUIRED>\n"
  "\n"
  "  <!-- Utility elements -->\n"
  "  <!ELEMENT letter EMPTY>\n"
  "  <!ATTLIST letter id ID #REQUIRED>\n"
  "  <!ATTLIST letter symbol CDATA #REQUIRED>\n"
  "\n"
  "  <!ELEMENT alphabet_array (value+)>\n"
  "\n"
  "  <!ELEMENT value (#PCDATA)>\n"
  "  <!ATTLIST value letter_id IDREF #REQUIRED>\n"
  "\n"
  "]>\n";

==> meme-5.5.1.tar.gz: meme-5.5.1/src/mhmm-dtd.h <==
char *mhmm_dtd = "<?xml version='1.0' encoding='UTF-8' standalone='yes'?>\n"
  "<!-- Document definition -->\n"
  "<!DOCTYPE MEME_HMM[\n"
  "\n"
  "  <!ELEMENT MEME_HMM (\n"
  "    command_line,\n"
  "    alphabet,\n"
  "    background_frequencies,\n"
  "    states\n"
  "  )>\n"
  "  <!ATTLIST MEME_HMM\n"
  "    version CDATA #REQUIRED\n"
  "    release_date CDATA #REQUIRED\n"
  "    type (linear|star|complete) #REQUIRED\n"
  "    motif_file CDATA #REQUIRED \n"
  "    sequence_file CDATA #IMPLIED \n"
  "    description CDATA #IMPLIED \n"
  "  >\n"
  "\n"
  "  <!ELEMENT command_line (#PCDATA)*>\n"
  "\n"
  "  <!ELEMENT alphabet (letter*)>\n"
  "  <!ATTLIST alphabet \n"
  "    id (amino_acid|nucleotide) #REQUIRED\n"
  "    length CDATA #REQUIRED\n"
  "  >\n"
  "\n"
  "  <!ELEMENT background_frequencies (alphabet_array)>\n"
  "\n"
  "  <!-- State elements -->\n"
  "  <!ELEMENT states (state*)>\n"
  "  <!ATTLIST states \n"
  "    num_states CDATA #REQUIRED\n"
  "    num_spacers CDATA #REQUIRED \n"
  "    spacer_states CDATA #REQUIRED \n"
  "  >\n"
  "\n"
  "  <!ELEMENT state (emission_probabilities?, transition*)>\n"
  "  <!ATTLIST state \n"
  "    id ID #REQUIRED\n"
  "    index CDATA #REQUIRED\n"
  "    type  (start|spacer|start_motif|mid_motif|end_motif|end) #REQUIRED\n"
  "    motif_index CDATA #IMPLIED\n"
  "    motif_id CDATA #IMPLIED\n"
  "    position CDATA #IMPLIED\n"
  "    id_char CDATA #REQUIRED\n"
  "    num_sites CDATA #REQUIRED\n"
  "  >\n"
  "\n"
  "  <!ELEMENT emission_probabilities (alphabet_array)>\n"
  "\n"
  "  <!ELEMENT transition (#PCDATA)>\n"
  "  <!ATTLIST transition to_state_index CDATA #REQUIRED>\n"
  "\n"
  "  <!-- Utility elements -->\n"
  "  <!ELEMENT letter EMPTY>\n"
  "  <!ATTLIST letter id ID #REQUIRED>\n"
  "  <!ATTLIST letter symbol CDATA #REQUIRED>\n"
  "\n"
  "  <!ELEMENT alphabet_array (value*)>\n"
  "\n"
  "  <!ELEMENT value (#PCDATA)>\n"
  "  <!ATTLIST value letter_id IDREF #REQUIRED>\n"
  "\n"
  "]>\n";
